@@ -17,7 +17,7 @@ if __name__ == '__main__':
         apps = []
 
         try:
-            for i in range(0, DOCKER_APP_COUNT):
+            for i in range(DOCKER_APP_COUNT):
                 app = tiny_app_apache(get_app_name(), get_app_version())
                 app.set_ini_parameter(
                     WebInterface='/%s' % app.app_name,
@@ -31,15 +31,15 @@ if __name__ == '__main__':
 
             appcenter.update()
 
-            for i in range(0, DOCKER_APP_COUNT):
+            for i in range(DOCKER_APP_COUNT):
                 apps[i].install()
 
-            for i in range(0, DOCKER_APP_COUNT):
+            for i in range(DOCKER_APP_COUNT):
                 apps[i].verify(joined=False)
                 apps[i].configure_tinyapp_modproxy()
                 apps[i].verify_basic_modproxy_settings_tinyapp()
 
         finally:
-            for i in range(0, len(apps)):
+            for i in range(len(apps)):
                 apps[i].uninstall()
                 apps[i].remove()
